@@ -5,7 +5,7 @@ from cc_py_commons.config.env import app_config
 from cc_py_commons.utils.logger import logger
 
 # Initializes s3fs to use AWS KEY/SECRET and returns URL for file
-s3 = s3fs.S3FileSystem(key=app_config.AWS_ACCESS_KEY_ID, secret=app_config.AWS_SECRET_ACCESS_KEY)
+s3 = s3fs.S3FileSystem(key=app_config.ACCESS_KEY_ID, secret=app_config.SECRET_ACCESS_KEY)
 
 
 def does_exist(bucket, filename):
